@@ -3,7 +3,7 @@
    xsane-back-gtk.c
 
    Oliver Rauch <Oliver.Rauch@rauch-domain.de>
-   Copyright (C) 1998-2004 Oliver Rauch
+   Copyright (C) 1998-2005 Oliver Rauch
    This file is part of the XSANE package.
 
    This program is free software; you can redistribute it and/or modify
@@ -183,7 +183,10 @@ SANE_Status xsane_control_option(SANE_Handle handle, SANE_Int option, SANE_Actio
       if ((opt) && (!(opt->cap & SANE_CAP_SOFT_DETECT)))
       {
         DBG(DBG_warning, "WARNING: xsane_control_option(option = %d, action = %d): SANE_CAP_SOFT_DETECT is not set\n", option, action);
-       return SANE_STATUS_GOOD;
+        if (option > 0) /* continue for option == 0, otherwise we can not read this option */
+        {
+          return SANE_STATUS_GOOD;
+        }
       }
     }
 #endif
@@ -352,6 +355,14 @@ int xsane_back_gtk_make_path(size_t buf_size, char *buf, const char *prog_name,
           buf[len++] = '_'; 
          break;
 
+        case '*':	/* "*" -> "_" */
+          buf[len++] = '_'; 
+         break;
+
+        case '?':	/* "?" -> "_" */
+          buf[len++] = '_'; 
+         break;
+
 #ifdef _WIN32
         case ':':	/* ":" -> "_" */
           buf[len++] = '_'; 
@@ -400,7 +411,7 @@ int xsane_back_gtk_make_path(size_t buf_size, char *buf, const char *prog_name,
    int fd;
 
     uid = getuid();
-    snprintf(tmpbuf, sizeof(tmpbuf), "-%d-", uid);
+    snprintf(tmpbuf, sizeof(tmpbuf), "-%d-", (int) uid);
                                                              
     extra = strlen(tmpbuf);
     if (len + extra >= buf_size)
@@ -881,7 +892,7 @@ static void xsane_back_gtk_filetype_callback(GtkWidget *widget, gpointer data)
     {
       if ( (!strcasecmp(extension, ".pnm"))  || (!strcasecmp(extension, ".raw"))
         || (!strcasecmp(extension, ".png"))  || (!strcasecmp(extension, ".ps"))
-        || (!strcasecmp(extension, ".rgba"))
+        || (!strcasecmp(extension, ".pdf"))  || (!strcasecmp(extension, ".rgba"))
         || (!strcasecmp(extension, ".tiff")) || (!strcasecmp(extension, ".tif"))
         || (!strcasecmp(extension, ".text")) || (!strcasecmp(extension, ".txt"))
         || (!strcasecmp(extension, ".jpg"))  || (!strcasecmp(extension, ".jpeg"))
@@ -951,6 +962,12 @@ void xsane_back_gtk_filetype_menu_set_history(GtkWidget *xsane_filetype_option_m
     select_item = filetype_nr;
   }
 
+  filetype_nr++;
+  if ( (filetype) && (!strcasecmp(filetype, XSANE_FILETYPE_PDF)) )
+  {
+    select_item = filetype_nr;
+  }
+
 #ifdef SUPPORT_RGBA
   filetype_nr++;
   if ( (filetype) && (!strcasecmp(filetype, XSANE_FILETYPE_RGBA)) )
@@ -1007,6 +1024,16 @@ GtkWidget *xsane_back_gtk_filetype_menu_new(char *filetype, GtkSignalFunc filety
   }
 #endif
 
+  xsane_filetype_item = gtk_menu_item_new_with_label(MENU_ITEM_FILETYPE_PDF);
+  gtk_container_add(GTK_CONTAINER(xsane_filetype_menu), xsane_filetype_item);
+  g_signal_connect(GTK_OBJECT(xsane_filetype_item), "activate", filetype_callback, (void *) XSANE_FILETYPE_PDF);
+  gtk_widget_show(xsane_filetype_item);
+  filetype_nr++;
+  if ( (filetype) && (!strcasecmp(filetype, XSANE_FILETYPE_PDF)) )
+  {
+    select_item = filetype_nr;
+  }
+
 #ifdef HAVE_LIBPNG
 #ifdef HAVE_LIBZ
   xsane_filetype_item = gtk_menu_item_new_with_label(MENU_ITEM_FILETYPE_PNG);
@@ -1202,10 +1229,7 @@ int xsane_back_gtk_get_filename(const char *label, const char *default_name, siz
   DBG(DBG_info, "xsane_back_gtk_get_filename: waiting for user action\n");
   while (!cancel && !ok && !destroy)
   {
-    if (gtk_events_pending())
-    {
-      gtk_main_iteration();
-    }
+    gtk_main_iteration();
   }
 
   if (ok)
@@ -2112,7 +2136,7 @@ void xsane_back_gtk_set_sensitivity(int sensitive)
 
 void xsane_set_sensitivity(SANE_Int sensitivity)
 {
-  DBG(DBG_proc, "xsane_set_sensitivity\n");
+  DBG(DBG_proc, "xsane_set_sensitivity(%d)\n", sensitivity);
 
   if (xsane.shell)
   {
@@ -2150,7 +2174,20 @@ void xsane_set_sensitivity(SANE_Int sensitivity)
 
   if (xsane.fax_dialog)
   {
-    gtk_widget_set_sensitive(xsane.fax_dialog, sensitivity);
+    /* do not change sensitivity of fax_dialog, we want the progress bar */
+    /* to be sensitive */
+    gtk_widget_set_sensitive(xsane.fax_project_box, sensitivity);
+    gtk_widget_set_sensitive(xsane.fax_project_exists, sensitivity);
+    gtk_widget_set_sensitive(xsane.fax_project_entry_box, sensitivity);
+  }
+
+  if (xsane.mail_dialog)
+  {
+    /* do not change sensitivity of mail_dialog, we want the progress bar */
+    /* to be sensitive */
+    gtk_widget_set_sensitive(xsane.mail_project_box, sensitivity);
+    gtk_widget_set_sensitive(xsane.mail_project_exists, sensitivity);
+    gtk_widget_set_sensitive(xsane.mail_project_entry_box, sensitivity);
   }
 
   if (xsane.batch_scan_dialog)
@@ -2159,15 +2196,6 @@ void xsane_set_sensitivity(SANE_Int sensitivity)
     gtk_widget_set_sensitive(xsane.batch_scan_action_box, sensitivity);
   }
 
-#if 0
-  xsane_back_gtk_set_sensitivity(sensitivity);
-#endif
-
-  while (gtk_events_pending()) /* make sure set_sensitivity is displayed */
-  {
-    gtk_main_iteration();
-  }
-
   xsane.sensitivity = sensitivity;
 }
 
