@@ -3,7 +3,7 @@
    xsane.h
 
    Oliver Rauch <Oliver.Rauch@rauch-domain.de>
-   Copyright (C) 1998-2004 Oliver Rauch
+   Copyright (C) 1998-2005 Oliver Rauch
    This file is part of the XSANE package.
 
    This program is free software; you can redistribute it and/or modify
@@ -85,10 +85,10 @@
 
 /* ---------------------------------------------------------------------------------------------------------------------- */
 
-#define XSANE_VERSION		"0.95"
+#define XSANE_VERSION		"0.98"
 #define XSANE_AUTHOR		"Oliver Rauch"
 #define XSANE_COPYRIGHT		"Oliver Rauch"
-#define XSANE_DATE		"1998-2004"
+#define XSANE_DATE		"1998-2005"
 #define XSANE_EMAIL		"Oliver.Rauch@xsane.org"
 #define XSANE_HOMEPAGE		"http://www.xsane.org"
 #define XSANE_COPYRIGHT_TXT	XSANE_DATE " " XSANE_COPYRIGHT
@@ -108,6 +108,32 @@
 # define _WIN32
 #endif
 
+#ifdef HAVE_LIBPNG
+#ifdef HAVE_LIBZ
+# define XSANE_DEFAULT_MAILTYPE XSANE_FILETYPE_PNG
+# define XSANE_ACTIVATE_MAIL
+#endif
+#endif
+
+#ifndef XSANE_DEFAULT_MAILTYPE
+#ifdef HAVE_LIBJPEG
+# define XSANE_DEFAULT_MAILTYPE XSANE_FILETYPE_JPEG
+# define XSANE_ACTIVATE_MAIL
+#endif
+#endif
+
+#ifndef XSANE_DEFAULT_MAILTYPE
+#ifdef HAVE_LIBTIFF
+# define XSANE_DEFAULT_MAILTYPE XSANE_FILETYPE_TIFF
+# define XSANE_ACTIVATE_MAIL
+#endif
+#endif
+
+#ifndef XSANE_DEFAULT_MAILTYPE
+# define XSANE_DEFAULT_MAILTYPE XSANE_FILETYPE_PNM
+#endif
+
+
 /* ---------------------------------------------------------------------------------------------------------------------- */
 
 #ifndef SLASH
@@ -261,14 +287,6 @@
 
 /* ---------------------------------------------------------------------------------------------------------------------- */
 
-#ifdef HAVE_LIBPNG
-#ifdef HAVE_LIBZ
-# define XSANE_ACTIVATE_MAIL
-#endif
-#endif
-
-/* ---------------------------------------------------------------------------------------------------------------------- */
-
 enum
 {
   XSANE_PATH_LOCAL_SANE = 0,
@@ -446,7 +464,6 @@ extern void xsane_batch_scan_add(void);
 #define FAXPOSTSCRIPTOPT	""
 #define FAXNORMALOPT		"-l"
 #define FAXFINEOPT		"-m"
-#define FAXVIEWER 	 	"gv"
 #define FAXCONVERTPSTOPNM  	"gs -dNOPAUSE -dBATCH -q -r204 -sDEVICE=pnm -sOutputFile="
 #define MAILPROJECT 	    	"mailproject"
 #define MAILCOMMAND 	 	"sendmail"
@@ -516,7 +533,7 @@ extern void xsane_batch_scan_add(void);
 enum
 {
  XSANE_UNKNOWN, XSANE_PNM, XSANE_JPEG, XSANE_PNG, XSANE_PS, XSANE_TIFF, XSANE_RGBA,
- XSANE_RAW16, XSANE_PNM16, XSANE_TEXT
+ XSANE_RAW16, XSANE_PNM16, XSANE_TEXT, XSANE_PDF
 };
  
 /* ---------------------------------------------------------------------------------------------------------------------- */
@@ -637,6 +654,7 @@ typedef struct Xsane
     GtkWidget *fax_project_exists;
     GtkWidget *fax_project_not_exists;
     GtkWidget *fax_project_entry;
+    GtkWidget *fax_project_entry_box;
     GtkWidget *fax_receiver_entry;
     GtkProgressBar *fax_progress_bar;
 
@@ -646,6 +664,7 @@ typedef struct Xsane
     GtkWidget *mail_project_exists;
     GtkWidget *mail_project_not_exists;
     GtkWidget *mail_project_entry;
+    GtkWidget *mail_project_entry_box;
     GtkWidget *mail_receiver_entry;
     GtkWidget *mail_subject_entry;
     GtkWidget *mail_text_widget;
@@ -665,7 +684,6 @@ typedef struct Xsane
     Preview   *preview;
     int preview_gamma_size;
     int mode;
-    int medium_nr;
 
     int main_window_fixed;
     int mode_selection;
@@ -801,9 +819,13 @@ typedef struct Xsane
     u_char *histogram_gamma_data_red, *histogram_gamma_data_green, *histogram_gamma_data_blue;
     u_char *histogram_medium_gamma_data_red, *histogram_medium_gamma_data_green, *histogram_medium_gamma_data_blue;
 
+    char *fax_status;
     char *fax_filename;
     char *fax_receiver;
 
+    float mail_progress_val;
+    int   mail_progress_size;
+    int   mail_progress_bytes;
     char *mail_status;
     char *mail_filename;
     char *mail_receiver;
